Rain

Struct Rain 

pub struct Rain(pub f32);
Component containing the rain level. Valid values are in [0, 1] with 0 being no rain and 1 being full rain.

Tuple Fields

0: f32

Methods from Deref<Target = f32>

1.43.0 · Source

pub const RADIX: u32 = 2

pub const BITS: u32 = 32

1.43.0 · Source

pub const MANTISSA_DIGITS: u32 = 24

1.43.0 · Source

pub const DIGITS: u32 = 6

1.43.0 · Source

pub const EPSILON: f32 = 1.19209290e-07_f32

1.43.0 · Source

pub const MIN: f32 = -3.40282347e+38_f32

1.43.0 · Source

pub const MIN_POSITIVE: f32 = 1.17549435e-38_f32

1.43.0 · Source

pub const MAX: f32 = 3.40282347e+38_f32

1.43.0 · Source

pub const MIN_EXP: i32 = -125

1.43.0 · Source

pub const MAX_EXP: i32 = 128

1.43.0 · Source

pub const MIN_10_EXP: i32 = -37

1.43.0 · Source

pub const MAX_10_EXP: i32 = 38

1.43.0 · Source

pub const NAN: f32

1.43.0 · Source

pub const INFINITY: f32

1.43.0 · Source

pub const NEG_INFINITY: f32

pub const MAX_EXACT_INTEGER: i32

pub const MIN_EXACT_INTEGER: i32

pub const SIGN_MASK: u32 = 0x8000_0000

pub const EXPONENT_MASK: u32 = 0x7f80_0000

pub const MANTISSA_MASK: u32 = 0x007f_ffff

1.62.0 · Source

pub fn total_cmp(&self, other: &f32) -> Ordering

Returns the ordering between self and other.

Unlike the standard partial comparison between floating point numbers, this comparison always produces an ordering in accordance to the totalOrder predicate as defined in the IEEE 754 (2008 revision) floating point standard. The values are ordered in the following sequence:

  • negative quiet NaN
  • negative signaling NaN
  • negative infinity
  • negative numbers
  • negative subnormal numbers
  • negative zero
  • positive zero
  • positive subnormal numbers
  • positive numbers
  • positive infinity
  • positive signaling NaN
  • positive quiet NaN.

The ordering established by this function does not always agree with the PartialOrd and PartialEq implementations of f32. For example, they consider negative and positive zero equal, while total_cmp doesn’t.

The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.

Example
struct GoodBoy {
    name: String,
    weight: f32,
}

let mut bois = vec![
    GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
    GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
    GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
    GoodBoy { name: "Chonk".to_owned(), weight: f32::INFINITY },
    GoodBoy { name: "Abs. Unit".to_owned(), weight: f32::NAN },
    GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];

bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));

// `f32::NAN` could be positive or negative, which will affect the sort order.
if f32::NAN.is_sign_negative() {
    assert!(bois.into_iter().map(|b| b.weight)
        .zip([f32::NAN, -5.0, 0.1, 10.0, 99.0, f32::INFINITY].iter())
        .all(|(a, b)| a.to_bits() == b.to_bits()))
} else {
    assert!(bois.into_iter().map(|b| b.weight)
        .zip([-5.0, 0.1, 10.0, 99.0, f32::INFINITY, f32::NAN].iter())
        .all(|(a, b)| a.to_bits() == b.to_bits()))
}