pub struct WeatherBundle {
pub rain: Rain,
pub thunder: Thunder,
}Expand description
Bundle containing rain and thunder components. chunkedge_weather allows
this to be added to clients and chunk layer entities.
Fields
rain: Rainthunder: ThunderTrait Implementations
Sourceimpl Bundle for WeatherBundle
impl Bundle for WeatherBundle
Sourceimpl Default for WeatherBundle
impl Default for WeatherBundle
Sourcefn default() -> WeatherBundle
fn default() -> WeatherBundle
Returns the “default value” for a type. Read more
Sourceimpl DynamicBundle for WeatherBundle
impl DynamicBundle for WeatherBundle
Sourceunsafe fn get_components(
ptr: MovingPtr<'_, Self>,
func: &mut impl FnMut(StorageType, OwningPtr<'_>),
)
unsafe fn get_components( ptr: MovingPtr<'_, Self>, func: &mut impl FnMut(StorageType, OwningPtr<'_>), )
Moves the components out of the bundle. Read more
Sourceunsafe fn apply_effect(
ptr: MovingPtr<'_, MaybeUninit<Self>>,
func: &mut EntityWorldMut<'_>,
)
unsafe fn apply_effect( ptr: MovingPtr<'_, MaybeUninit<Self>>, func: &mut EntityWorldMut<'_>, )
Applies the after-effects of spawning this bundle. Read more
Sourceimpl PartialEq for WeatherBundle
impl PartialEq for WeatherBundle
Sourcefn eq(&self, other: &WeatherBundle) -> bool
fn eq(&self, other: &WeatherBundle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WeatherBundle
impl PartialOrd for WeatherBundle
impl BundleFromComponents for WeatherBundle
impl StructuralPartialEq for WeatherBundle